import { __awaiter, __generator } from 'tslib';
import { routeSplit, registerPlugin } from '@scullyio/scully';
import { createClient } from 'contentful';

var contentfulRoutePlugin = function (route, conf) { return __awaiter(void 0, void 0, void 0, function () {
    var createPath, contentfulClientOptions, client, entries, e_1, details;
    return __generator(this, function (_a) {
        switch (_a.label) {
            case 0:
                createPath = routeSplit(route).createPath;
                _a.label = 1;
            case 1:
                _a.trys.push([1, 3, , 4]);
                contentfulClientOptions = {
                    space: conf.config.spaceId,
                    accessToken: conf.config.accessToken
                };
                if (conf.config.host) {
                    contentfulClientOptions.host = conf.config.host;
                }
                if (conf.config.environment) {
                    contentfulClientOptions.environment = conf.config.environment;
                }
                if (!conf.config.spaceId) {
                    throw 'A space ID is required. Check if setting is correct.';
                }
                if (!conf.config.accessToken) {
                    throw 'Authorization error. Check if setting is correct.';
                }
                if (!conf.config.contentType) {
                    throw 'A content type is required. Check if setting is correct.';
                }
                client = createClient(contentfulClientOptions);
                return [4 /*yield*/, client.getEntries({
                        content_type: conf.config.contentType
                    })];
            case 2:
                entries = _a.sent();
                return [2 /*return*/, entries.items.map(function (e) { return ({
                        route: createPath(e.sys.id),
                        type: 'contentful',
                        data: e.fields
                    }); })];
            case 3:
                e_1 = _a.sent();
                details = void 0;
                if (e_1.code === "ENOTFOUND") {
                    details = "You seem to be offline";
                }
                else if (e_1.code === "SELF_SIGNED_CERT_IN_CHAIN") {
                    console.error(
                    // tslint:disable-next-line:max-line-length
                    "We couldn't make a secure connection to your contentful space. Please check if you have any self-signed SSL certificates installed.");
                }
                else if (e_1.response) {
                    if (e_1.response.status === 404) {
                        // host and space used to generate url
                        details = "Endpoint not found. Check if host and spaceId settings are correct";
                    }
                    else if (e_1.response.status === 401) {
                        // authorization error
                        details = "Authorization error. Check if accessToken and environment are correct";
                    }
                }
                else if (e_1) {
                    console.error("Accessing your Contentful space failed.\n      " + (details ? "\n" + details + "\n" : ""));
                }
                return [3 /*break*/, 4];
            case 4: return [2 /*return*/];
        }
    });
}); };
var validator = function (_a) {
    var config = _a.config;
    var errors = [];
    if (!config.spaceId) {
        errors.push('A Space ID is required. You can find your Space ID in your Contentful account.');
    }
    if (!config.accessToken) {
        errors.push('An access token is required. You can find your access tokens in your Contentful account');
    }
    if (!config.contentType) {
        errors.push('A content type is required.');
    }
    return errors;
};
var ɵ0 = validator;
var Contentful = 'contentful';
registerPlugin('router', Contentful, contentfulRoutePlugin, validator);

/*
 * Public API Surface of scully-plugin-contentful
 */

/**
 * Generated bundle index. Do not edit.
 */

export { Contentful };
//# sourceMappingURL=scully-plugin-contentful.js.map
